**Example 1: 范例**



Input: 

```
tccli wedata CreateFolder --cli-unfold-argument  \
    --ProjectId 1 \
    --ParentsFolderId  \
    --FolderName wb555
```

Output: 
```
{
    "Response": {
        "RequestId": "4fb76d7a-2a54-4b42-8405-bb22483eb2b3",
        "Data": {
            "Id": "c4440a5d-0cd6-11ed-8909-bc97e105ba60"
        }
    }
}
```

